==> rendition-18.4.1.tgz: package/dist_esm5/extra/JsonSchemaRenderer/widgets/index.js <==
import values from 'lodash/values';
import ArrayWidget from './ArrayWidget';
import BadgeWidget from './BadgeWidget';
import ButtonGroupWidget from './ButtonGroupWidget';
import ButtonWidget from './ButtonWidget';
import CheckboxWidget from './CheckboxWidget';
import DropDownButtonWidget from './DropDownButtonWidget';
import HeadingWidget from './HeadingWidget';
import HighlightedNameWidget from './HighlightedNameWidget';
import ImgWidget from './ImgWidget';
import LinkWidget from './LinkWidget';
import ListWidget from './ListWidget';
import MarkdownWidget from './MarkdownWidget';
import ObjectWidget from './ObjectWidget';
import TagWidget from './TagWidget';
import TxtWidget from './TxtWidget';
import { JsonTypes } from '../types';
import { withOptionProps } from './widget-util';
export { WidgetWrapperUiOptions } from './ui-options';
export { getObjectPropertyNames } from './widget-util';
export { default as WidgetMeta } from './WidgetMeta';
var widgets = {};
values(JsonTypes).reduce(function (acc, jsonType) {
    acc[jsonType] = {};
    return acc;
}, widgets);
var allWidgets = {};
[
    ArrayWidget,
    BadgeWidget,
    ButtonGroupWidget,
    ButtonWidget,
    CheckboxWidget,
    DropDownButtonWidget,
    HeadingWidget,
    HighlightedNameWidget,
    ImgWidget,
    LinkWidget,
    ListWidget,
    MarkdownWidget,
    ObjectWidget,
    TagWidget,
    TxtWidget,
].reduce(function (acc, widget) {
    var widgetName = widget.name.replace(/Widget$/, '');
    var wrappedWidget = widget.uiOptions
        ? withOptionProps(widget.uiOptions)(widget)
        : widget;
    acc[widgetName] = wrappedWidget;
    if (widget.supportedTypes) {
        widget.supportedTypes.forEach(function (jsonType) {
            widgets[jsonType][widgetName] = wrappedWidget;
        });
    }
    return acc;
}, allWidgets);
widgets.object.default = allWidgets.Object;
widgets.string.default = allWidgets.Txt;
widgets.null.default = allWidgets.Txt;
widgets.integer.default = allWidgets.Txt;
widgets.number.default = allWidgets.Txt;
widgets.boolean.default = allWidgets.Checkbox;
widgets.array.default = allWidgets.Array;
widgets.default = {
    default: allWidgets.Txt,
};
export default widgets;

==> rendition-18.8.0.tgz: package/dist_esm5/extra/JsonSchemaRenderer/widgets/index.js <==
import values from 'lodash/values';
import ArrayWidget from './ArrayWidget';
import BadgeWidget from './BadgeWidget';
import ButtonGroupWidget from './ButtonGroupWidget';
import ButtonWidget from './ButtonWidget';
import CheckboxWidget from './CheckboxWidget';
import DropDownButtonWidget from './DropDownButtonWidget';
import HeadingWidget from './HeadingWidget';
import HighlightedNameWidget from './HighlightedNameWidget';
import ImgWidget from './ImgWidget';
import LinkWidget from './LinkWidget';
import ListWidget from './ListWidget';
import MarkdownWidget from './MarkdownWidget';
import MermaidWidget from './MermaidWidget';
import ObjectWidget from './ObjectWidget';
import TagWidget from './TagWidget';
import TxtWidget from './TxtWidget';
import { JsonTypes } from '../types';
import { withOptionProps } from './widget-util';
export { WidgetWrapperUiOptions } from './ui-options';
export { getObjectPropertyNames } from './widget-util';
export { default as WidgetMeta } from './WidgetMeta';
var widgets = {};
values(JsonTypes).reduce(function (acc, jsonType) {
    acc[jsonType] = {};
    return acc;
}, widgets);
var allWidgets = {};
[
    ArrayWidget,
    BadgeWidget,
    ButtonGroupWidget,
    ButtonWidget,
    CheckboxWidget,
    DropDownButtonWidget,
    HeadingWidget,
    HighlightedNameWidget,
    ImgWidget,
    LinkWidget,
    ListWidget,
    MarkdownWidget,
    MermaidWidget,
    ObjectWidget,
    TagWidget,
    TxtWidget,
].reduce(function (acc, widget) {
    var widgetName = widget.name.replace(/Widget$/, '');
    var wrappedWidget = widget.uiOptions
        ? withOptionProps(widget.uiOptions)(widget)
        : widget;
    acc[widgetName] = wrappedWidget;
    if (widget.supportedTypes) {
        widget.supportedTypes.forEach(function (jsonType) {
            widgets[jsonType][widgetName] = wrappedWidget;
        });
    }
    return acc;
}, allWidgets);
widgets.object.default = allWidgets.Object;
widgets.string.default = allWidgets.Txt;
widgets.null.default = allWidgets.Txt;
widgets.integer.default = allWidgets.Txt;
widgets.number.default = allWidgets.Txt;
widgets.boolean.default = allWidgets.Txt;
widgets.array.default = allWidgets.Array;
widgets.default = {
    default: allWidgets.Txt,
};
export var formatWidgetMap = {
    markdown: allWidgets.Markdown,
    mermaid: allWidgets.Mermaid,
    email: allWidgets.Link,
    uri: allWidgets.Link,
};
export default widgets;
